"""
Basic field probe example

Change the fl_address variable to match your laser probe interface.

You can use PyVISA to get a list of available resources:
import visa
rm = visa.ResourceManager()
print(rm.list_resources())
"""

from ardrivers import arfieldprobe

fl_address = 'GPIB0::4::INSTR'

# Create an AR_FieldProbe object and initialize the VISA session
fl = arfieldprobe.AR_FieldProbe()
fl.initialize(fl_address)

# Print information about the laser probe interface
interface_id = fl.query_interface_id()
print('Laser probe interface:')
print('Model:', interface_id['model'])
print('Serial Number:', interface_id['serial'])
print('Firmware revision:', interface_id['firmware'])

# Print information about the attached probe
probe_id = fl.query_probe_id()
print('Probe:')
print('Model:', probe_id['model'])
print('Serial Number:', probe_id['serial'])
print('Firmware revision:', probe_id['firmware'])
print('Linearization date:', probe_id['linearization'])

# Read data from the probe
data = fl.read_data()
print('X:', data['x'])
print('Y:', data['y'])
print('Z:', data['z'])
print('Composite:', data['c'])

fl.close()
